@@ -26,6 +26,9 @@ DELETE_SQL_FILE = os.path.join(here, "dml/delete.sql")
 GET_COLUMN_NAMES_SQL_FILE = os.path.join(
     here, "information_schema/get_column_names.sql"
 )
+GET_PRIMITIVE_COLUMN_NAMES_SQL_FILE = os.path.join(
+    here, "information_schema/get_primitive_column_names.sql"
+)
 GET_TABLE_NAMES_SQL_FILE = os.path.join(here, "information_schema/get_table_names.sql")
 INSERT_SQL_FILE = os.path.join(here, "dml/insert.sql")
 UPSERT_SQL_FILE = os.path.join(here, "dml/upsert.sql")
